package com.nokia.dingtalkapi.config;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.redis.connection.RedisStandaloneConfiguration;
import org.springframework.data.redis.connection.lettuce.LettuceConnectionFactory;
import org.springframework.data.redis.core.RedisTemplate;

import com.nokia.dingtalkapi.properties.DingtalkProperties;
import com.nokia.dingtalkapi.properties.DingtalkRedisProperties;

/**
 * 根据配置考虑是否配置独立的redis
 * 使用lettuce框架，仅支持独立部署的redis
 */
@Configuration
@ConditionalOnBean(DingtalkProperties.class)
@ConditionalOnProperty(name = "dingtalk.api.redis.enable", havingValue = "true", matchIfMissing = false)
@EnableConfigurationProperties(DingtalkRedisProperties.class)
public class DingtalkRedisAutoConfiguration {

    @Autowired
    private DingtalkRedisProperties properties;

    /**
     * 注入独立的redisTemplate（不同连接地址），需要注入独立的连接工厂
     * 
     * @return
     */
    @Bean(name = "dingtalkRedisConnectionFactory")
    public LettuceConnectionFactory dingtalkRedisConnectionFactory() {
        return new LettuceConnectionFactory(new RedisStandaloneConfiguration(properties.getHost(),
                properties.getPort()));
    }

    @Bean("dingtalkRedisTemplate")
    public RedisTemplate<String, Object> dingtalkRedisTemplate(
            @Autowired @Qualifier("dingtalkRedisConnectionFactory") LettuceConnectionFactory lettuceConnectionFactory) {
        RedisTemplate<String, Object> redisTemplate = new RedisTemplate<>();
        redisTemplate.setConnectionFactory(lettuceConnectionFactory);
        redisTemplate.afterPropertiesSet();
        return redisTemplate;
    }
}
